# Module to use python with office tools
You can find here various tool which can help you in creation back office tools.
# Prerequisite:
pip install sqlalchemy
pip install pandas
pip install win32com
